#[repr(transparent)]pub struct CaptureH(pub u32);Expand description
Capture High Register
Tuple Fields
0: u32Implementations
Sourceimpl CaptureH
impl CaptureH
Sourcepub const fn capture_value(&self) -> u16
pub const fn capture_value(&self) -> u16
A read reflects the value of the upper 10 bits of the central 42-bits EVTIMER at the time the last capture signal was generated by the CPU (using CMSIS C function “__SEV();”).
Sourcepub const fn set_capture_value(&mut self, val: u16)
pub const fn set_capture_value(&mut self, val: u16)
A read reflects the value of the upper 10 bits of the central 42-bits EVTIMER at the time the last capture signal was generated by the CPU (using CMSIS C function “__SEV();”).