nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Evtimerh

Struct Evtimerh 

#[repr(transparent)]
pub struct Evtimerh(pub u32);
EVTIMER High Register

Tuple Fields

0: u32

Implementations

Source

impl Evtimerh

pub const fn evtimer_count_value(&self) -> u16

A read reflects the current value of the upper 10 bits of the 42-bits EVTIMER. Note there is only one EVTIMER, readable from all domains.

pub const fn set_evtimer_count_value(&mut self, val: u16)

A read reflects the current value of the upper 10 bits of the 42-bits EVTIMER. Note there is only one EVTIMER, readable from all domains.