#[repr(transparent)]pub struct CaptureL(pub u32);Expand description
Capture Low Register
Tuple Fields
0: u32Implementations
Sourceimpl CaptureL
impl CaptureL
Sourcepub const fn capture_value(&self) -> u32
pub const fn capture_value(&self) -> u32
A read reflects the value of the lower 32 bits of the central 42-bits EVTIMER at the time the last capture signal was generated by the CPU (using CMSIS C function “__SEV();”).
Sourcepub const fn set_capture_value(&mut self, val: u32)
pub const fn set_capture_value(&mut self, val: u32)
A read reflects the value of the lower 32 bits of the central 42-bits EVTIMER at the time the last capture signal was generated by the CPU (using CMSIS C function “__SEV();”).