#[repr(transparent)]pub struct Evtimerh(pub u32);Expand description
EVTIMER High Register
Tuple Fields
0: u32Implementations
Sourceimpl Evtimerh
impl Evtimerh
Sourcepub const fn evtimer_count_value(&self) -> u16
pub const fn evtimer_count_value(&self) -> u16
A read reflects the current value of the upper 10 bits of the 42-bits EVTIMER. Note there is only one EVTIMER, readable from all domains.
Sourcepub const fn set_evtimer_count_value(&mut self, val: u16)
pub const fn set_evtimer_count_value(&mut self, val: u16)
A read reflects the current value of the upper 10 bits of the 42-bits EVTIMER. Note there is only one EVTIMER, readable from all domains.